from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class PkiCertSummaryResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The commonName property
    common_name: Optional[str] = None
    # The expiration property
    expiration: Optional[int] = None
    # The revoked property
    revoked: Optional[bool] = None
    # The serialNumber property
    serial_number: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> PkiCertSummaryResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: PkiCertSummaryResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return PkiCertSummaryResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "commonName": lambda n : setattr(self, 'common_name', n.get_str_value()),
            "expiration": lambda n : setattr(self, 'expiration', n.get_int_value()),
            "revoked": lambda n : setattr(self, 'revoked', n.get_bool_value()),
            "serialNumber": lambda n : setattr(self, 'serial_number', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("commonName", self.common_name)
        writer.write_int_value("expiration", self.expiration)
        writer.write_bool_value("revoked", self.revoked)
        writer.write_str_value("serialNumber", self.serial_number)
        writer.write_additional_data_value(self.additional_data)
    

